==> explorify-0.0.2-py3-none-any.whl: explorify/eda/stats/inferential/profile.py <==
#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# ================================================================================================ #
# Project    : Explorify                                                                           #
# Version    : 0.1.0                                                                               #
# Python     : 3.10.12                                                                             #
# Filename   : /explorify/eda/stats/inferential/profile.py                                         #
# ------------------------------------------------------------------------------------------------ #
# Author     : John James                                                                          #
# Email      : john.james.ai.studio@gmail.com                                                      #
# URL        : https://github.com/variancexplained/explorify                                       #
# ------------------------------------------------------------------------------------------------ #
# Created    : Tuesday August 22nd 2023 07:45:44 pm                                                #
# Modified   : Sunday June 9th 2024 11:26:30 am                                                    #
# ------------------------------------------------------------------------------------------------ #
# License    : MIT License                                                                         #
# Copyright  : (c) 2023 John James                                                                 #
# ================================================================================================ #
from __future__ import annotations

from dataclasses import dataclass, fields

from explorify import DataClass
from explorify.utils.io import IOService

# ------------------------------------------------------------------------------------------------ #
STAT_CONFIG = "config/stats.yml"


# ------------------------------------------------------------------------------------------------ #
@dataclass
class StatTestProfile(DataClass):
    """Abstract base class defining the interface for statistical tests.

    Interface inspired by: https://doc.dataiku.com/dss/latest/statistics/tests.html
    """

    id: str
    name: str = None
    description: str = None
    statistic: str = None
    analysis: str = None  # one of ANALYSIS_TYPES
    hypothesis: str = None  # One of HYPOTHESIS_TYPES
    H0: str = None
    parametric: bool = None
    min_sample_size: int = None
    assumptions: str = None
    use_when: str = None
    a_type: str = None  # Variable type in ['categorical','numeric']
    b_type: str = (
        None  # Variable type in ['categorical','numeric'] for the b variable, if any
    )

    @classmethod
    def create(cls, id) -> StatTestProfile:
        """Loads the values from the statistical tests file"""
        profiles = IOService.read(STAT_CONFIG)
        profile = profiles[id]
        fieldlist = {f.name for f in fields(cls) if f.init}
        filtered_dict = {k: v for k, v in profile.items() if k in fieldlist}
        filtered_dict["id"] = id
        return cls(**filtered_dict)

==> explorify-0.1.6-py3-none-any.whl: explorify/eda/stats/inferential/profile.py <==
#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# ================================================================================================ #
# Project    : Explorify                                                                           #
# Version    : 0.1.0                                                                               #
# Python     : 3.10.12                                                                             #
# Filename   : /explorify/eda/stats/inferential/profile.py                                         #
# ------------------------------------------------------------------------------------------------ #
# Author     : John James                                                                          #
# Email      : john.james.ai.studio@gmail.com                                                      #
# URL        : https://github.com/variancexplained/explorify                                       #
# ------------------------------------------------------------------------------------------------ #
# Created    : Tuesday August 22nd 2023 07:45:44 pm                                                #
# Modified   : Sunday January 26th 2025 05:53:26 pm                                                #
# ------------------------------------------------------------------------------------------------ #
# License    : MIT License                                                                         #
# Copyright  : (c) 2023 John James                                                                 #
# ================================================================================================ #
from __future__ import annotations

from dataclasses import dataclass, field, fields
from typing import Optional

from explorify import DataClass
from explorify.utils.io import IOService

# ------------------------------------------------------------------------------------------------ #
STAT_CONFIG = "config/stats.yml"


# ------------------------------------------------------------------------------------------------ #
@dataclass
class StatTestProfile(DataClass):
    """Abstract base class defining the interface for statistical tests.

    Interface inspired by: https://doc.dataiku.com/dss/latest/statistics/tests.html
    """

    id: str
    name: Optional[str] = field(default=None)
    description: Optional[str] = field(default=None)
    statistic: Optional[str] = field(default=None)
    analysis: Optional[str] = field(default=None)  # one of ANALYSIS_TYPES
    hypothesis: Optional[str] = field(default=None)  # One of HYPOTHESIS_TYPES
    H0: Optional[str] = field(default=None)
    parametric: Optional[bool] = field(default=None)
    min_sample_size: Optional[int] = field(default=None)
    assumptions: Optional[str] = field(default=None)
    use_when: Optional[str] = field(default=None)
    a_type: Optional[str] = field(
        default=None
    )  # Variable type in ['categorical','numeric']
    b_type: Optional[str] = field(default=None)

    @classmethod
    def create(cls, id) -> StatTestProfile:
        """Loads the values from the statistical tests file"""
        profiles = IOService.read(STAT_CONFIG)
        profile = profiles[id]
        fieldlist = {f.name for f in fields(cls) if f.init}
        filtered_dict = {k: v for k, v in profile.items() if k in fieldlist}
        filtered_dict["id"] = id
        return cls(**filtered_dict)
